==> mongodb-ui-components-2.7.14.tgz: package/components/nav/components/panel-top/search.js <==
const React = require('react')
const { searchIcon } = require('../nav-icons')

class SearchInput extends React.PureComponent {
  constructor (props) {
    super(props)
    this.state = { isOpen: false }

    this.setState = this.setState.bind(this)
    this.onBtnPress = this.onBtnPress.bind(this)
    this.toggle = this.toggle.bind(this)

    this._openInput = { marginRight: '-35px', opacity: 1 }
    this._closedInput = { marginRight: '-210px', opacity: 0 }
  }

  componentDidMount () {
    this.links = document.querySelector('.nav-panel-top__links')
  }

  onSearch () {
    const value = encodeURIComponent(this._input.value)
    window.location.href = `${this.props.searchUrl}${value}`
  }

  onBtnPress (e) {
    e.preventDefault()
    e.stopPropagation()

    if (!this.state.isOpen) {
      this._input.focus()
      this.toggle(true)
    } else if (!this._input.value) {
      this.toggle(false)
    } else {
      this.onSearch()
    }
  }

  toggle (isOpen) {
    this.setState({ isOpen })
    this.links.classList.toggle('nav-panel-top__links--hidden', isOpen)
  }

  render () {
    const { isOpen } = this.state

    return (
      <span className='flex flex--wrap'>
        <input
          style={isOpen ? this._openInput : this._closedInput}
          className='input nav-panel-top__input'
          onBlur={() => { window.setTimeout(() => { this.toggle(false) }, 50) }}
          onKeyUp={(e) => { return e.keyCode === 13 && this.onSearch() }}
          ref={(c) => { this._input = c }}
          placeholder='search' />
        <button
          className={
            `flex flex--center-all flex--wrap nav-panel-top__search ${
              isOpen ? 'nav-panel-top__search--active' : ''}`
          }
          onClick={this.onBtnPress}
          onTouchStart={this.onBtnPress}
        >{ searchIcon }</button>
      </span>
    )
  }
}

const { string } = React.PropTypes

SearchInput.propTypes = {
  searchUrl: string
}

module.exports = SearchInput

==> mongodb-ui-components-3.1.1.tgz: package/components/nav/components/panel-top/search.js <==
const React = require('react')
const { searchIcon } = require('../nav-icons')

class SearchInput extends React.PureComponent {
  constructor (props) {
    super(props)
    this.state = { isOpen: false }

    this.onBtnPress = this.onBtnPress.bind(this)
    this.open = this.toggle.bind(this, true)
    this.close = this.toggle.bind(this, false)

    this.openInputStyle = { marginRight: '-35px', opacity: 1 }
    this.closedInputStyle = { marginRight: '-210px', opacity: 0 }
  }

  componentDidMount () {
    this.links = document.querySelector('.nav-panel-top__links')
  }

  onSearch () {
    const value = encodeURIComponent(this.inputEl.value)
    window.location.href = `${this.props.searchUrl}${value}`
  }

  onBtnPress (e) {
    e.preventDefault()
    e.stopPropagation()

    if (!this.state.isOpen) {
      this.inputEl.focus()
      this.open()
    } else if (!this.inputEl.value) {
      this.close()
    } else {
      this.onSearch()
    }
  }

  toggle (isOpen) {
    this.setState({ isOpen })
    this.links.classList.toggle('nav-panel-top__links--hidden', isOpen)
  }

  render () {
    const { isOpen } = this.state

    return (
      <span className='nav-panel-top__search-container flex flex--wrap'>
        <input
          style={isOpen ? this.openInputStyle : this.closedInputStyle}
          className='input nav-panel-top__input'
          onBlur={() => { setTimeout(this.close, 50) }}
          onKeyUp={(e) => { return e.keyCode === 13 && this.onSearch() }}
          ref={(c) => { this.inputEl = c }}
          placeholder='search' />
        <button
          className={
            `flex flex--center-all flex--wrap nav-panel-top__search ${
              isOpen ? 'nav-panel-top__search--active' : ''
            }`
          }
          onClick={this.onBtnPress}
          onTouchStart={this.onBtnPress}
        >{ searchIcon }</button>
      </span>
    )
  }
}

const { string } = React.PropTypes

SearchInput.propTypes = {
  searchUrl: string
}

module.exports = SearchInput
